Commit: patch 9.1.1033: Vim9: compiling abstract method fails without return

2 views
Skip to first unread message

Christian Brabandt

unread,
Jan 18, 2025, 11:30:12 AM1/18/25
to vim...@googlegroups.com
patch 9.1.1033: Vim9: compiling abstract method fails without return

Commit: https://github.com/vim/vim/commit/7c92e888946903fa26b377efbc98c8f83e9188b8
Author: Ernie Rael <err...@raelity.com>
Date: Sat Jan 18 17:26:39 2025 +0100

patch 9.1.1033: Vim9: compiling abstract method fails without return

Problem: Vim9: compiling abstract method fails without return
(Aliaksei Budavei)
Solution: don't require return for an abstract method
(Ernie Rael)

fixes: #15432
related: ##15441
closes: #16469

Signed-off-by: Ernie Rael <err...@raelity.com>
Signed-off-by: Yegappan Lakshmanan <yega...@yahoo.com>
Signed-off-by: Christian Brabandt <c...@256bit.org>

diff --git a/src/testdir/test_vim9_class.vim b/src/testdir/test_vim9_class.vim
index fc0edeb5b..cac8b63c7 100644
--- a/src/testdir/test_vim9_class.vim
+++ b/src/testdir/test_vim9_class.vim
@@ -6458,6 +6458,39 @@ def Test_abstract_method()
assert_equal('foo', A.Foo())
END
v9.CheckSourceSuccess(lines)
+
+ # Invoke method returning a value through the abstract class. See #15432.
+ lines =<< trim END
+ vim9script
+
+ abstract class A
+ abstract def String(): string
+ endclass
+
+ class B extends A
+ def String(): string
+ return 'B'
+ enddef
+ endclass
+
+ def F(o: A)
+ assert_equal('B', o.String())
+ enddef
+ F(B.new())
+ END
+ v9.CheckSourceSuccess(lines)
+
+ # Invoke abstract method returning a value does not compile
+ lines =<< trim END
+ vim9script
+
+ abstract class A
+ abstract def String(): string
+ return 'X'
+ enddef
+ endclass
+ END
+ v9.CheckScriptFailure(lines, "E1318: Not a valid command in a class: return 'X'")
enddef

" Test for calling a class method from a subclass
diff --git a/src/version.c b/src/version.c
index 6e6b651a1..ba4115977 100644
--- a/src/version.c
+++ b/src/version.c
@@ -704,6 +704,8 @@ static char *(features[]) =

static int included_patches[] =
{ /* Add new patch number below this line */
+/**/
+ 1034,
/**/
1033,
/**/
diff --git a/src/vim9compile.c b/src/vim9compile.c
index fa02871e8..338415e85 100644
--- a/src/vim9compile.c
+++ b/src/vim9compile.c
@@ -4917,9 +4917,10 @@ compile_def_function(
goto erret;
ufunc->uf_args_visible = ufunc->uf_args.ga_len;

- // Compiling a function in an interface is done to get the function type.
- // No code is actually compiled.
- if (ufunc->uf_class != NULL && IS_INTERFACE(ufunc->uf_class))
+ // Compiling an abstract method or a function in an interface is done to
+ // get the function type. No code is actually compiled.
+ if (ufunc->uf_class != NULL && (IS_INTERFACE(ufunc->uf_class)
+ || IS_ABSTRACT_METHOD(ufunc)))
{
ufunc->uf_def_status = UF_NOT_COMPILED;
ret = OK;
Reply all
Reply to author
Forward
0 new messages